==> haskell-lsp-types-1.6.0.1-61-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp-types
version:              1.6.0.1
visibility:           public
id:                   lsp-types-1.6.0.1-EbXi7nqThAk8EPWs1KGH8W
key:                  lsp-types-1.6.0.1-EbXi7nqThAk8EPWs1KGH8W
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:
    Haskell library for the Microsoft Language Server Protocol, data types

description:
    An implementation of the types to allow language implementors to
    support the Language Server Protocol for their specific language.

category:             Development
abi:                  3cb7c6301e7b2c39e36e96c2a7543fbc
exposed:              True
exposed-modules:
    Data.IxMap Language.LSP.Types Language.LSP.Types.Capabilities
    Language.LSP.Types.Lens Language.LSP.Types.SMethodMap

hidden-modules:
    Language.LSP.Types.CallHierarchy Language.LSP.Types.Cancellation
    Language.LSP.Types.ClientCapabilities Language.LSP.Types.CodeAction
    Language.LSP.Types.CodeLens Language.LSP.Types.Command
    Language.LSP.Types.Common Language.LSP.Types.Completion
    Language.LSP.Types.Configuration Language.LSP.Types.Declaration
    Language.LSP.Types.Definition Language.LSP.Types.Diagnostic
    Language.LSP.Types.DocumentColor Language.LSP.Types.DocumentFilter
    Language.LSP.Types.DocumentHighlight
    Language.LSP.Types.DocumentLink Language.LSP.Types.DocumentSymbol
    Language.LSP.Types.FoldingRange Language.LSP.Types.Formatting
    Language.LSP.Types.Hover Language.LSP.Types.Implementation
    Language.LSP.Types.Initialize Language.LSP.Types.Location
    Language.LSP.Types.LspId Language.LSP.Types.MarkupContent
    Language.LSP.Types.Method Language.LSP.Types.Message
    Language.LSP.Types.Parsing Language.LSP.Types.Progress
    Language.LSP.Types.Registration Language.LSP.Types.References
    Language.LSP.Types.Rename Language.LSP.Types.SelectionRange
    Language.LSP.Types.ServerCapabilities
    Language.LSP.Types.SemanticTokens Language.LSP.Types.SignatureHelp
    Language.LSP.Types.StaticRegistrationOptions
    Language.LSP.Types.TextDocument Language.LSP.Types.TypeDefinition
    Language.LSP.Types.Uri Language.LSP.Types.Utils
    Language.LSP.Types.Window Language.LSP.Types.WatchedFiles
    Language.LSP.Types.WorkspaceEdit
    Language.LSP.Types.WorkspaceFolders
    Language.LSP.Types.WorkspaceSymbol Language.LSP.Types.Uri.OsPath

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lsp-types-1.6.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lsp-types-1.6.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lsp-types-1.6.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp-types
hs-libraries:         HSlsp-types-1.6.0.1-EbXi7nqThAk8EPWs1KGH8W
depends:
    Diff-0.4.1-8NUfR4WKqY5H9Ttf0Koorw
    aeson-2.1.2.1-5BFfk7iI7w6HPWzhbIRzqn base-4.17.2.1 binary-0.8.9.1
    containers-0.6.7 data-default-0.7.1.1-1dWAwpuUe04Bvh1yMI7wxn
    deepseq-1.4.8.0 dlist-1.0-I6FB5Nlk17hG16fxQzZSEb exceptions-0.10.5
    filepath-1.4.2.2 hashable-1.4.4.0-HayYj9uqgN4KUEsvzi6aVt
    lens-5.3-4eslcvGQhMj5JgydAUw2Le mod-0.2.0.1-DE0iwn6dBPrL6kkpH77dT4
    mtl-2.2.2 network-uri-2.6.4.2-69U48sX3jSI9NKFFT4iJZQ
    safe-0.3.21-95XFMbugIpQGQaoszxvDo2
    scientific-0.3.7.0-KrMKCvnfUrQHIZNLkrXCwo
    some-1.0.6-C8SVhXoLo1W43DiM5WqKp8 template-haskell-2.19.0.0
    text-2.0.2 unordered-containers-0.2.20-2eRdi4Eno3wAApPXuoC33k

haddock-interfaces:   /usr/share/doc/haskell-lsp-types/html/lsp-types.haddock
haddock-html:         /usr/share/doc/haskell-lsp-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lsp-types-1.6.0.1-65-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp-types
version:              1.6.0.1
visibility:           public
id:                   lsp-types-1.6.0.1-G3Xvup4znTyBBsuZlFc00V
key:                  lsp-types-1.6.0.1-G3Xvup4znTyBBsuZlFc00V
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:
    Haskell library for the Microsoft Language Server Protocol, data types

description:
    An implementation of the types to allow language implementors to
    support the Language Server Protocol for their specific language.

category:             Development
abi:                  961b7019ad4b0872b85aedcbaed3aeb5
exposed:              True
exposed-modules:
    Data.IxMap Language.LSP.Types Language.LSP.Types.Capabilities
    Language.LSP.Types.Lens Language.LSP.Types.SMethodMap

hidden-modules:
    Language.LSP.Types.CallHierarchy Language.LSP.Types.Cancellation
    Language.LSP.Types.ClientCapabilities Language.LSP.Types.CodeAction
    Language.LSP.Types.CodeLens Language.LSP.Types.Command
    Language.LSP.Types.Common Language.LSP.Types.Completion
    Language.LSP.Types.Configuration Language.LSP.Types.Declaration
    Language.LSP.Types.Definition Language.LSP.Types.Diagnostic
    Language.LSP.Types.DocumentColor Language.LSP.Types.DocumentFilter
    Language.LSP.Types.DocumentHighlight
    Language.LSP.Types.DocumentLink Language.LSP.Types.DocumentSymbol
    Language.LSP.Types.FoldingRange Language.LSP.Types.Formatting
    Language.LSP.Types.Hover Language.LSP.Types.Implementation
    Language.LSP.Types.Initialize Language.LSP.Types.Location
    Language.LSP.Types.LspId Language.LSP.Types.MarkupContent
    Language.LSP.Types.Method Language.LSP.Types.Message
    Language.LSP.Types.Parsing Language.LSP.Types.Progress
    Language.LSP.Types.Registration Language.LSP.Types.References
    Language.LSP.Types.Rename Language.LSP.Types.SelectionRange
    Language.LSP.Types.ServerCapabilities
    Language.LSP.Types.SemanticTokens Language.LSP.Types.SignatureHelp
    Language.LSP.Types.StaticRegistrationOptions
    Language.LSP.Types.TextDocument Language.LSP.Types.TypeDefinition
    Language.LSP.Types.Uri Language.LSP.Types.Utils
    Language.LSP.Types.Window Language.LSP.Types.WatchedFiles
    Language.LSP.Types.WorkspaceEdit
    Language.LSP.Types.WorkspaceFolders
    Language.LSP.Types.WorkspaceSymbol Language.LSP.Types.Uri.OsPath

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lsp-types-1.6.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lsp-types-1.6.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lsp-types-1.6.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp-types
hs-libraries:         HSlsp-types-1.6.0.1-G3Xvup4znTyBBsuZlFc00V
depends:
    Diff-0.4.1-7aKWbaxEjXuGNL7kuqoq7g
    aeson-2.1.2.1-6jLf9XnWqJCFwZgyNgcXK5 base-4.17.2.1 binary-0.8.9.1
    containers-0.6.7 data-default-0.7.1.1-7mS5xpY4EnxodGGT6vPB1
    deepseq-1.4.8.0 dlist-1.0-3IsW2ghxYJNLBlqCManDLX exceptions-0.10.5
    filepath-1.4.2.2 hashable-1.4.4.0-8IAMfvJ5RiNBptVjfaEAIZ
    lens-5.3-FqQ28IkTmSZ8BNGxtZdro6 mod-0.2.0.1-6izn1C0KZUk5tcT61LIjcc
    mtl-2.2.2 network-uri-2.6.4.2-Ezz3DgCiNVkB3lRSna1Fn6
    safe-0.3.21-4IziazZYdjEuwuFTqrwKI
    scientific-0.3.7.0-HO6fZYKmOY5KBpmsmPggyV
    some-1.0.6-1SD3iHUG5HqJJvyBvrawCQ template-haskell-2.19.0.0
    text-2.0.2 unordered-containers-0.2.20-C8J7H3CMcSh2WWoYFsvixL

haddock-interfaces:   /usr/share/doc/haskell-lsp-types/html/lsp-types.haddock
haddock-html:         /usr/share/doc/haskell-lsp-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
